@@ -22,6 +22,6 @@
 
 #include "vfs.h"
 
-extern VFSConstructor vfs_local_vtable;
+VFSImpl * vfs_local_fopen (const char * uri, const char * mode, String & error);
 
 #endif /* LIBAUDCORE_VFS_LOCAL_H */
