@@ -23,22 +23,22 @@
 #include <libaudcore/tuple.h>
 #include <libaudcore/vfs.h>
 
-enum
+namespace audtag {
+
+enum class TagType
 {
-    TAG_TYPE_NONE = 0,
-    TAG_TYPE_APE,
+    None,
+    APE,
+    ID3v2
 };
 
-void tag_set_verbose (bool_t verbose);
+bool tuple_read (Tuple & tuple, VFSFile &fd);
+Index<char> image_read (VFSFile & handle);
 
-bool_t tag_tuple_read (Tuple * tuple, VFSFile *fd);
-bool_t tag_image_read (VFSFile * handle, void * * data, int64_t * size);
-
-/* new_type specifies the type of tag (see the TAG_TYPE_* enum) that should be
+/* new_type specifies the type of tag (see the TagType enum) that should be
  * written if the file does not have any existing tag. */
-bool_t tag_tuple_write (const Tuple * tuple, VFSFile * handle, int new_type);
+bool tuple_write (const Tuple & tuple, VFSFile & handle, TagType new_type);
 
-/* deprecated, use tag_tuple_write */
-bool_t tag_tuple_write_to_file (Tuple * tuple, VFSFile * handle);
+}
 
 #endif /* AUDTAG_H */
