@@ -20,16 +20,16 @@
 #ifndef AUDTAG_ID3_COMMON_H
 #define AUDTAG_ID3_COMMON_H
 
-#include <stdint.h>
+#include <libaudcore/index.h>
 #include <libaudcore/tuple.h>
 
-void id3_associate_string (Tuple * tuple, int field, const char * data, int size);
-void id3_associate_int (Tuple * tuple, int field, const char * data, int size);
-void id3_decode_genre (Tuple * tuple, const char * data, int size);
-void id3_decode_comment (Tuple * tuple, const char * data, int size);
-void id3_decode_rva (Tuple * tuple, const char * data, int size);
+void id3_associate_string (Tuple & tuple, Tuple::Field field, const char * data, int size);
+void id3_associate_int (Tuple & tuple, Tuple::Field field, const char * data, int size);
+void id3_associate_length (Tuple & tuple, const char * data, int size);
+void id3_decode_genre (Tuple & tuple, const char * data, int size);
+void id3_decode_comment (Tuple & tuple, const char * data, int size);
+void id3_decode_rva (Tuple & tuple, const char * data, int size);
 
-bool_t id3_decode_picture (const char * data, int size, int * type,
- void * * image_data, int64_t * image_size);
+Index<char> id3_decode_picture (const char * data, int size);
 
 #endif
